<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * WC Authorize Net DPM order handler.
 *
 * @since 1.7.0
 */
class WC_Authorize_Net_Order_Handler {

	/**
	 * Constructor.
	 *
	 * @since 1.7.0
	 */
	public function __construct() {
		add_action( 'woocommerce_order_status_on-hold_to_processing', array( $this, 'maybe_capture_transaction' ) );
		add_action( 'woocommerce_order_status_on-hold_to_completed', array( $this, 'maybe_capture_transaction' ) );
		add_action( 'woocommerce_order_status_on-hold_to_cancelled', array( $this, 'maybe_void_transaction' ) );
		add_action( 'woocommerce_order_status_on-hold_to_refunded', array( $this, 'maybe_void_transaction' ) );
	}

	/**
	 * Maybe capture the transaction when order status is updated.
	 *
	 * @since 1.7.0
	 *
	 * @param int $order_id Order ID.
	 */
	public function maybe_capture_transaction( $order_id ) {
		$order  = wc_get_order( $order_id );
		$method = wc_authorize_net_dpm_order_prop( $order, 'payment_method' );

		if ( 'authorize_net_dpm' !== $method ) {
			return;
		}

		if ( 'yes' === get_post_meta( $order_id, '_authorize_net_dpm_captured', true ) ) {
			return;
		}

		$resp = WC_Authorize_Net_API::capture( $order_id );
		if ( is_wp_error( $resp ) ) {
			$order->add_order_note( sprintf( __( 'Unable to capture the transaction in Authorize.Net: %s', 'woocommerce-gateway-authorize-net-dpm' ), $resp->get_error_message() ) );
			return;
		}

		$order->add_order_note( __( 'Successfully captured Authorize.Net transaction.', 'woocommerce-gateway-authorize-net-dpm' ) );

		update_post_meta( $order_id, '_authorize_net_dpm_captured', 'yes' );
	}

	/**
	 * Maybe void the transaction when order status is updated.
	 *
	 * @since 1.7.0
	 *
	 * @param int $order_id Order ID.
	 */
	public function maybe_void_transaction( $order_id ) {
		$order  = wc_get_order( $order_id );
		$method = wc_authorize_net_dpm_order_prop( $order, 'payment_method' );

		if ( 'authorize_net_dpm' !== $method ) {
			return;
		}

		if ( 'yes' === get_post_meta( $order_id, '_authorize_net_dpm_voided', true ) ) {
			return;
		}

		$resp = WC_Authorize_Net_API::void( $order_id );
		if ( is_wp_error( $resp ) ) {
			$order->add_order_note( sprintf( __( 'Unable to void the transaction in Authorize.Net: %s', 'woocommerce-gateway-authorize-net-dpm' ), $resp->get_error_message() ) );
			return;
		}

		$order->add_order_note( __( 'Successfully voided Authorize.Net transaction', 'woocommerce-gateway-authorize-net-dpm' ) );

		update_post_meta( $order_id, '_authorize_net_dpm_voided', 'yes' );
	}

}
